aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoradheli.tavares <adheli.tavares@est.tech>2024-04-10 14:12:28 +0100
committeradheli.tavares <adheli.tavares@est.tech>2024-04-10 14:41:20 +0100
commit5bd2e9091fa75bc41fce1667f5deb46ac5e94380 (patch)
treee493c0c7ae2695c42058cbdb5fc2488c94e7b267
parent12142469280ab15d3c38802e6be7d7676435c2b9 (diff)
Dependency management update
- including dependencies to pom.xml files only where they are used, avoiding extra dependencies being added in all packages. Issue-ID: POLICY-4945 Change-Id: I376ea0763190d55f254dc8f88b6fa5b89354e8b9 Signed-off-by: adheli.tavares <adheli.tavares@est.tech>
-rw-r--r--feature-lifecycle/pom.xml4
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java36
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java2
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingFeatureTest.java32
-rw-r--r--feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingManagerImplTest.java27
-rw-r--r--policy-core/pom.xml18
-rw-r--r--policy-domains/pom.xml12
-rw-r--r--policy-management/pom.xml49
-rw-r--r--policy-management/src/main/java/org/onap/policy/drools/controller/IndexedDroolsControllerFactory.java8
-rw-r--r--policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistenceConstants.java2
-rw-r--r--policy-management/src/main/java/org/onap/policy/drools/server/restful/RestManager.java40
-rw-r--r--policy-management/src/main/java/org/onap/policy/drools/system/Main.java3
-rw-r--r--policy-management/src/main/resources/openapi/openapi.yaml214
-rw-r--r--policy-management/src/main/resources/swagger/swagger.json264
-rw-r--r--policy-management/src/test/java/org/onap/policy/drools/server/restful/test/RestManagerTest.java232
-rw-r--r--policy-management/src/test/java/org/onap/policy/drools/system/PolicyEngineTest.java1
-rw-r--r--pom.xml4
17 files changed, 250 insertions, 698 deletions
diff --git a/feature-lifecycle/pom.xml b/feature-lifecycle/pom.xml
index 757f23b4..02b5be54 100644
--- a/feature-lifecycle/pom.xml
+++ b/feature-lifecycle/pom.xml
@@ -112,6 +112,10 @@
<groupId>commons-beanutils</groupId>
<artifactId>commons-beanutils</artifactId>
</dependency>
+ <dependency>
+ <groupId>io.prometheus</groupId>
+ <artifactId>simpleclient_hotspot</artifactId>
+ </dependency>
</dependencies>
</project>
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
index e9bd3cb5..c507b68a 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/FeatureTest.java
@@ -794,7 +794,7 @@ class FeatureTest {
if (msg == null) {
return;
}
- listener.onTopicEvent(CommInfrastructure.UEB, topic, msg);
+ listener.onTopicEvent(CommInfrastructure.KAFKA, topic, msg);
}
}
}
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingFeatureTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingFeatureTest.java
index 1b05e021..1eb9e361 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingFeatureTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingFeatureTest.java
@@ -298,7 +298,7 @@ class PoolingFeatureTest {
@Test
void testBeforeOffer() {
- assertFalse(pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1));
+ assertFalse(pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1));
verify(mgr1).beforeOffer(TOPIC1, EVENT1);
// ensure that the args were captured
@@ -307,7 +307,7 @@ class PoolingFeatureTest {
// ensure it's still in the map by re-invoking
- assertFalse(pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC2, EVENT2));
+ assertFalse(pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC2, EVENT2));
verify(mgr1).beforeOffer(TOPIC2, EVENT2);
// ensure that the new args were captured
@@ -315,12 +315,12 @@ class PoolingFeatureTest {
verify(mgr1).beforeInsert(TOPIC2, OBJECT2);
- assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.UEB, TOPIC1, EVENT1));
+ assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.KAFKA, TOPIC1, EVENT1));
}
@Test
void testBeforeOffer_NotFound() {
- assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.UEB, TOPIC1, EVENT1));
+ assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.KAFKA, TOPIC1, EVENT1));
}
@Test
@@ -329,28 +329,28 @@ class PoolingFeatureTest {
// manager will return true
when(mgr1.beforeOffer(any(), any())).thenReturn(true);
- assertTrue(pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1));
+ assertTrue(pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1));
verify(mgr1).beforeOffer(TOPIC1, EVENT1);
// ensure it's still in the map by re-invoking
- assertTrue(pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC2, EVENT2));
+ assertTrue(pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC2, EVENT2));
verify(mgr1).beforeOffer(TOPIC2, EVENT2);
- assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.UEB, TOPIC1, EVENT1));
+ assertFalse(pool.beforeOffer(controllerDisabled, CommInfrastructure.KAFKA, TOPIC1, EVENT1));
}
@Test
void testBeforeInsert() {
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1);
assertFalse(pool.beforeInsert(drools1, OBJECT1));
verify(mgr1).beforeInsert(TOPIC1, OBJECT1);
// ensure it's still in the map by re-invoking
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC2, EVENT2);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC2, EVENT2);
assertFalse(pool.beforeInsert(drools1, OBJECT2));
verify(mgr1).beforeInsert(TOPIC2, OBJECT2);
- pool.beforeOffer(controllerDisabled, CommInfrastructure.UEB, TOPIC2, EVENT2);
+ pool.beforeOffer(controllerDisabled, CommInfrastructure.KAFKA, TOPIC2, EVENT2);
assertFalse(pool.beforeInsert(droolsDisabled, OBJECT1));
}
@@ -375,7 +375,7 @@ class PoolingFeatureTest {
}
};
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1);
assertFalse(pool.beforeInsert(drools1, OBJECT1));
verify(mgr1, never()).beforeInsert(any(), any());
}
@@ -390,7 +390,7 @@ class PoolingFeatureTest {
}
};
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1);
assertFalse(pool.beforeInsert(drools1, OBJECT1));
verify(mgr1, never()).beforeInsert(any(), any());
}
@@ -406,7 +406,7 @@ class PoolingFeatureTest {
}
};
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1);
assertFalse(pool.beforeInsert(drools1, OBJECT1));
verify(mgr1, never()).beforeInsert(any(), any());
}
@@ -414,17 +414,17 @@ class PoolingFeatureTest {
@Test
void testBeforeInsert_NotFound() {
- pool.beforeOffer(controllerDisabled, CommInfrastructure.UEB, TOPIC2, EVENT2);
+ pool.beforeOffer(controllerDisabled, CommInfrastructure.KAFKA, TOPIC2, EVENT2);
assertFalse(pool.beforeInsert(droolsDisabled, OBJECT1));
}
@Test
void testAfterOffer() {
// this will create OfferArgs
- pool.beforeOffer(controller1, CommInfrastructure.UEB, TOPIC1, EVENT1);
+ pool.beforeOffer(controller1, CommInfrastructure.KAFKA, TOPIC1, EVENT1);
// this should clear them
- assertFalse(pool.afterOffer(controller1, CommInfrastructure.UEB, TOPIC2, EVENT2, true));
+ assertFalse(pool.afterOffer(controller1, CommInfrastructure.KAFKA, TOPIC2, EVENT2, true));
assertFalse(pool.beforeInsert(drools1, OBJECT1));
verify(mgr1, never()).beforeInsert(any(), any());
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingManagerImplTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingManagerImplTest.java
index ac60ae27..98300683 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingManagerImplTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/PoolingManagerImplTest.java
@@ -37,6 +37,7 @@ import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import java.util.LinkedList;
+import java.util.Objects;
import java.util.Properties;
import java.util.Queue;
import java.util.concurrent.CountDownLatch;
@@ -504,7 +505,7 @@ class PoolingManagerImplTest {
}
@Test
- void testOnTopicEvent() throws Exception {
+ void testOnTopicEvent() {
startMgr();
StartState st = (StartState) mgr.getCurrent();
@@ -517,16 +518,16 @@ class PoolingManagerImplTest {
String msg = ser.encodeMsg(hb);
- mgr.onTopicEvent(CommInfrastructure.UEB, MY_TOPIC, msg);
+ mgr.onTopicEvent(CommInfrastructure.KAFKA, MY_TOPIC, msg);
assertInstanceOf(QueryState.class, mgr.getCurrent());
}
@Test
- void testOnTopicEvent_NullEvent() throws Exception {
+ void testOnTopicEvent_NullEvent() {
startMgr();
- assertThatCode(() -> mgr.onTopicEvent(CommInfrastructure.UEB, TOPIC2, null)).doesNotThrowAnyException();
+ assertThatCode(() -> mgr.onTopicEvent(CommInfrastructure.KAFKA, TOPIC2, null)).doesNotThrowAnyException();
}
@Test
@@ -563,12 +564,12 @@ class PoolingManagerImplTest {
@Test
void testHandleExternalCommInfrastructureStringStringString_NullReqId() throws Exception {
- validateHandleReqId(null);
+ validateHandleReqId();
}
@Test
void testHandleExternalCommInfrastructureStringStringString_EmptyReqId() throws Exception {
- validateHandleReqId("");
+ validateHandleReqId();
}
@Test
@@ -717,7 +718,7 @@ class PoolingManagerImplTest {
String msg = ser.encodeMsg(hb);
- mgr.onTopicEvent(CommInfrastructure.UEB, MY_TOPIC, msg);
+ mgr.onTopicEvent(CommInfrastructure.KAFKA, MY_TOPIC, msg);
assertInstanceOf(QueryState.class, mgr.getCurrent());
}
@@ -726,7 +727,7 @@ class PoolingManagerImplTest {
void testHandleInternal_IoEx() throws Exception {
startMgr();
- mgr.onTopicEvent(CommInfrastructure.UEB, MY_TOPIC, "invalid message");
+ mgr.onTopicEvent(CommInfrastructure.KAFKA, MY_TOPIC, "invalid message");
assertInstanceOf(StartState.class, mgr.getCurrent());
}
@@ -746,7 +747,7 @@ class PoolingManagerImplTest {
String msg = ser.encodeMsg(hb);
- mgr.onTopicEvent(CommInfrastructure.UEB, MY_TOPIC, msg);
+ mgr.onTopicEvent(CommInfrastructure.KAFKA, MY_TOPIC, msg);
assertInstanceOf(StartState.class, mgr.getCurrent());
}
@@ -859,7 +860,7 @@ class PoolingManagerImplTest {
String msg = ser.encodeMsg(hb);
- mgr.onTopicEvent(CommInfrastructure.UEB, MY_TOPIC, msg);
+ mgr.onTopicEvent(CommInfrastructure.KAFKA, MY_TOPIC, msg);
assertInstanceOf(QueryState.class, mgr.getCurrent());
@@ -870,7 +871,7 @@ class PoolingManagerImplTest {
assertEquals(1, latch.getCount());
}
- private void validateHandleReqId(String requestId) throws PoolingFeatureException {
+ private void validateHandleReqId() {
startMgr();
assertFalse(mgr.beforeInsert(TOPIC2, DECODED_EVENT));
@@ -887,7 +888,7 @@ class PoolingManagerImplTest {
verify(topicMessageManager, times(START_PUB)).publish(any());
}
- private void validateUnhandled() throws PoolingFeatureException {
+ private void validateUnhandled() {
startMgr();
assertFalse(mgr.beforeInsert(TOPIC2, DECODED_EVENT));
}
@@ -985,7 +986,7 @@ class PoolingManagerImplTest {
@Override
protected Object decodeEventWrapper(DroolsController drools2, String topic2, String event) {
- if (drools2 == drools && TOPIC2.equals(topic2) && event == THE_EVENT) {
+ if (drools2 == drools && TOPIC2.equals(topic2) && Objects.equals(event, THE_EVENT)) {
return DECODED_EVENT;
} else {
return null;
diff --git a/policy-core/pom.xml b/policy-core/pom.xml
index 35e64a76..948a3f14 100644
--- a/policy-core/pom.xml
+++ b/policy-core/pom.xml
@@ -51,20 +51,14 @@
</dependency>
<dependency>
+ <groupId>org.mvel</groupId>
+ <artifactId>mvel2</artifactId>
+ <version>2.5.2.Final</version>
+ </dependency>
+
+ <dependency>
<groupId>org.kie</groupId>
<artifactId>kie-ci</artifactId>
- <!--
- Issue: 2 of 2
- Excluding these 2 dependencies in order to force upgrade security fixes
- identified. As declared above. Any changes here should be reflected above
- and vice versa.
- -->
- <exclusions>
- <exclusion>
- <groupId>org.apache.ant</groupId>
- <artifactId>ant</artifactId>
- </exclusion>
- </exclusions>
</dependency>
<dependency>
diff --git a/policy-domains/pom.xml b/policy-domains/pom.xml
index 2667b714..36d6ba64 100644
--- a/policy-domains/pom.xml
+++ b/policy-domains/pom.xml
@@ -3,7 +3,7 @@
ONAP
================================================================================
Copyright (C) 2020 AT&T Intellectual Property. All rights reserved.
- Modifications Copyright (C) 2023 Nordix Foundation.
+ Modifications Copyright (C) 2023-2024 Nordix Foundation.
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -35,7 +35,6 @@
<description>domain policies</description>
<dependencies>
-
<dependency>
<groupId>org.projectlombok</groupId>
<artifactId>lombok</artifactId>
@@ -45,27 +44,28 @@
<groupId>com.google.code.gson</groupId>
<artifactId>gson</artifactId>
</dependency>
-
<dependency>
<groupId>com.openpojo</groupId>
<artifactId>openpojo</artifactId>
<scope>test</scope>
</dependency>
-
<dependency>
<groupId>org.onap.policy.common</groupId>
<artifactId>utils</artifactId>
<version>${policy.common.version}</version>
<scope>test</scope>
</dependency>
-
<dependency>
<groupId>org.onap.policy.drools-pdp</groupId>
<artifactId>policy-utils</artifactId>
<version>${project.version}</version>
<scope>test</scope>
</dependency>
-
+ <dependency>
+ <groupId>org.onap.policy.models</groupId>
+ <artifactId>policy-models-examples</artifactId>
+ <version>${policy.models.version}</version>
+ </dependency>
</dependencies>
</project>
diff --git a/policy-management/pom.xml b/policy-management/pom.xml
index 86303584..16ee74eb 100644
--- a/policy-management/pom.xml
+++ b/policy-management/pom.xml
@@ -4,7 +4,7 @@
ONAP Policy Engine - Drools PDP
================================================================================
Copyright (C) 2017-2022 AT&T Intellectual Property. All rights reserved.
- Modifications Copyright (C) 2020,2023 Nordix Foundation.
+ Modifications Copyright (C) 2020, 2023-2024 Nordix Foundation.
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -38,6 +38,7 @@
<build>
<plugins>
<plugin>
+ <groupId>org.apache.maven.plugins</groupId>
<artifactId>maven-assembly-plugin</artifactId>
<executions>
<execution>
@@ -81,6 +82,7 @@
</executions>
</plugin>
<plugin>
+ <groupId>org.apache.maven.plugins</groupId>
<artifactId>maven-resources-plugin</artifactId>
<executions>
<execution>
@@ -226,13 +228,11 @@
<artifactId>utils</artifactId>
<version>${policy.common.version}</version>
</dependency>
-
<dependency>
<groupId>org.onap.policy.models</groupId>
<artifactId>policy-models-pdp</artifactId>
<version>${policy.models.version}</version>
</dependency>
-
<dependency>
<groupId>org.eclipse.jetty</groupId>
<artifactId>jetty-server</artifactId>
@@ -241,11 +241,6 @@
<groupId>org.eclipse.jetty</groupId>
<artifactId>jetty-servlet</artifactId>
</dependency>
-
- <dependency>
- <groupId>com.google.code.gson</groupId>
- <artifactId>gson</artifactId>
- </dependency>
<dependency>
<groupId>com.fatboyindustrial.gson-javatime-serialisers</groupId>
<artifactId>gson-javatime-serialisers</artifactId>
@@ -259,11 +254,23 @@
<groupId>org.apache.commons</groupId>
<artifactId>commons-collections4</artifactId>
</dependency>
-
- <!-- if we don't explicitly specify the version here, we seem to end up
- with version 1.4 (as a dependency to drools-core). This version is
- not compatible with 'saClientLibrary' version 1.2.1-oss
- -->
+ <dependency>
+ <groupId>org.apache.commons</groupId>
+ <artifactId>commons-jexl3</artifactId>
+ </dependency>
+ <dependency>
+ <groupId>org.glassfish.jersey.inject</groupId>
+ <artifactId>jersey-hk2</artifactId>
+ </dependency>
+ <dependency>
+ <groupId>io.prometheus</groupId>
+ <artifactId>simpleclient_servlet_jakarta</artifactId>
+ </dependency>
+ <dependency>
+ <groupId>io.prometheus</groupId>
+ <artifactId>simpleclient_hotspot</artifactId>
+ <scope>runtime</scope>
+ </dependency>
<dependency>
<groupId>commons-codec</groupId>
<artifactId>commons-codec</artifactId>
@@ -273,6 +280,10 @@
<artifactId>logback-classic</artifactId>
</dependency>
<dependency>
+ <groupId>org.apache.kafka</groupId>
+ <artifactId>kafka-clients</artifactId>
+ </dependency>
+ <dependency>
<groupId>org.springframework</groupId>
<artifactId>spring-test</artifactId>
<scope>test</scope>
@@ -309,6 +320,18 @@
<groupId>io.swagger.core.v3</groupId>
<artifactId>swagger-annotations</artifactId>
</dependency>
+ <dependency>
+ <groupId>io.swagger.core.v3</groupId>
+ <artifactId>swagger-jaxrs2-servlet-initializer-v2-jakarta</artifactId>
+ </dependency>
+ <dependency>
+ <groupId>io.swagger.core.v3</groupId>
+ <artifactId>swagger-jaxrs2-jakarta</artifactId>
+ </dependency>
+ <dependency>
+ <groupId>jakarta.servlet</groupId>
+ <artifactId>jakarta.servlet-api</artifactId>
+ </dependency>
</dependencies>
</project>
diff --git a/policy-management/src/main/java/org/onap/policy/drools/controller/IndexedDroolsControllerFactory.java b/policy-management/src/main/java/org/onap/policy/drools/controller/IndexedDroolsControllerFactory.java
index 1965e22f..7f28f9bb 100644
--- a/policy-management/src/main/java/org/onap/policy/drools/controller/IndexedDroolsControllerFactory.java
+++ b/policy-management/src/main/java/org/onap/policy/drools/controller/IndexedDroolsControllerFactory.java
@@ -258,13 +258,7 @@ class IndexedDroolsControllerFactory implements DroolsControllerFactory {
private String getPropertyTopicPrefix(Topic topic) {
boolean isSource = topic instanceof TopicSource;
var commInfra = topic.getTopicCommInfrastructure();
- if (commInfra == CommInfrastructure.UEB) {
- if (isSource) {
- return PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + ".";
- } else {
- return PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS + ".";
- }
- } else if (commInfra == CommInfrastructure.NOOP) {
+ if (commInfra == CommInfrastructure.NOOP) {
if (isSource) {
return PolicyEndPointProperties.PROPERTY_NOOP_SOURCE_TOPICS + ".";
} else {
diff --git a/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistenceConstants.java b/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistenceConstants.java
index ba6c5e71..dba6d4c1 100644
--- a/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistenceConstants.java
+++ b/policy-management/src/main/java/org/onap/policy/drools/persistence/SystemPersistenceConstants.java
@@ -32,7 +32,7 @@ public final class SystemPersistenceConstants {
public static final String DEFAULT_CONFIGURATION_DIR = "config";
/**
- * Persistence Manager. For now it is a file-based properties management, In the future, it will
+ * Persistence Manager. For now, it is a file-based properties management, In the future, it will
* probably be DB based, so manager implementation will change.
*/
@Getter
diff --git a/policy-management/src/main/java/org/onap/policy/drools/server/restful/RestManager.java b/policy-management/src/main/java/org/onap/policy/drools/server/restful/RestManager.java
index ec06882f..48cd8140 100644
--- a/policy-management/src/main/java/org/onap/policy/drools/server/restful/RestManager.java
+++ b/policy-management/src/main/java/org/onap/policy/drools/server/restful/RestManager.java
@@ -1392,7 +1392,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}")
+ @Path("engine/topics/sources/{comm: kafka|noop}")
public Response commSources(
@PathParam("comm") String comm) {
if (!checkValidNameInput(comm)) {
@@ -1405,9 +1405,6 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
List<TopicSource> sources = new ArrayList<>();
var status = Status.OK;
switch (CommInfrastructure.valueOf(comm.toUpperCase())) {
- case UEB:
- sources.addAll(TopicEndpointManager.getManager().getUebTopicSources());
- break;
case NOOP:
sources.addAll(TopicEndpointManager.getManager().getNoopTopicSources());
break;
@@ -1427,7 +1424,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}")
+ @Path("engine/topics/sinks/{comm: kafka|noop}")
public Response commSinks(
@PathParam("comm") String comm) {
if (!checkValidNameInput(comm)) {
@@ -1440,9 +1437,6 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
List<TopicSink> sinks = new ArrayList<>();
var status = Status.OK;
switch (CommInfrastructure.valueOf(comm.toUpperCase())) {
- case UEB:
- sinks.addAll(TopicEndpointManager.getManager().getUebTopicSinks());
- break;
case NOOP:
sinks.addAll(TopicEndpointManager.getManager().getNoopTopicSinks());
break;
@@ -1462,7 +1456,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}")
public Response sourceTopic(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1478,7 +1472,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}")
public Response sinkTopic(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1494,7 +1488,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/events")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/events")
public Response sourceEvents(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1510,7 +1504,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/events")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/events")
public Response sinkEvents(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1526,7 +1520,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/switches")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/switches")
public Response commSourceTopicSwitches(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1538,7 +1532,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@GET
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/switches")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/switches")
public Response commSinkTopicSwitches(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1550,7 +1544,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@PUT
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/switches/lock")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/switches/lock")
public Response commSourceTopicLock(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1564,7 +1558,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@DELETE
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/switches/lock")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/switches/lock")
public Response commSourceTopicUnlock(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1578,7 +1572,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@PUT
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/switches/activation")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/switches/activation")
public Response commSourceTopicActivation(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1592,7 +1586,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@DELETE
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/switches/activation")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/switches/activation")
public Response commSourceTopicDeactivation(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1606,7 +1600,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@PUT
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/switches/lock")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/switches/lock")
public Response commSinkTopicLock(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1620,7 +1614,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@DELETE
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/switches/lock")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/switches/lock")
public Response commSinkTopicUnlock(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1634,7 +1628,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@PUT
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/switches/activation")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/switches/activation")
public Response commSinkTopicActivation(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1648,7 +1642,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@DELETE
- @Path("engine/topics/sinks/{comm: ueb|kafka|noop}/{topic}/switches/activation")
+ @Path("engine/topics/sinks/{comm: kafka|noop}/{topic}/switches/activation")
public Response commSinkTopicDeactivation(
@PathParam("comm") String comm,
@PathParam("topic") String topic) {
@@ -1676,7 +1670,7 @@ public class RestManager implements SwaggerApi, DefaultApi, FeaturesApi, InputsA
*/
@Override
@PUT
- @Path("engine/topics/sources/{comm: ueb|kafka|noop}/{topic}/events")
+ @Path("engine/topics/sources/{comm: kafka|noop}/{topic}/events")
@Consumes(MediaType.TEXT_PLAIN)
public Response commEventOffer(
@PathParam("comm") String comm,
diff --git a/policy-management/src/main/java/org/onap/policy/drools/system/Main.java b/policy-management/src/main/java/org/onap/policy/drools/system/Main.java
index 3d167352..f0530d05 100644
--- a/policy-management/src/main/java/org/onap/policy/drools/system/Main.java
+++ b/policy-management/src/main/java/org/onap/policy/drools/system/Main.java
@@ -3,6 +3,7 @@
* ONAP
* ================================================================================
* Copyright (C) 2017-2021 AT&T Intellectual Property. All rights reserved.
+ * Modifications Copyright (C) 2024 Nordix Foundation.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -124,7 +125,7 @@ public class Main {
try {
engineProperties = SystemPersistenceConstants.getManager().getEngineProperties();
} catch (IllegalArgumentException iae) {
- logger.warn("Main: engine properties not found. Using default configuration.", iae);
+ logger.warn("Main: engine properties not found. Using default configuration. {}", iae.getMessage());
engineProperties = PolicyEngineConstants.getManager().defaultTelemetryConfig();
}
diff --git a/policy-management/src/main/resources/openapi/openapi.yaml b/policy-management/src/main/resources/openapi/openapi.yaml
index 80a3ae63..2e20dd98 100644
--- a/policy-management/src/main/resources/openapi/openapi.yaml
+++ b/policy-management/src/main/resources/openapi/openapi.yaml
@@ -2238,7 +2238,7 @@ paths:
tags:
- pdp-d-telemetry
summary: Retrieves the managed topic sources
- description: Network Topic Sources Agregation
+ description: Network Topic Sources Aggregation
operationId: sources
responses:
200:
@@ -2255,7 +2255,7 @@ paths:
tags:
- pdp-d-telemetry
summary: Retrieves the managed topic sinks
- description: Network Topic Sinks Agregation
+ description: Network Topic Sinks Aggregation
operationId: sinks
responses:
200:
@@ -2338,7 +2338,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
responses:
200:
@@ -2363,7 +2363,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
responses:
200:
@@ -2389,7 +2389,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2412,7 +2412,7 @@ paths:
tags:
- pdp-d-telemetry
summary: Retrieves a managed topic sink
- description: This is a Network Communicaton Endpoint destination of messages
+ description: This is a Network Communication Endpoint destination of messages
from the Engine
operationId: sinkTopic
parameters:
@@ -2421,7 +2421,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2453,7 +2453,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2483,7 +2483,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2524,7 +2524,7 @@ paths:
tags:
- pdp-d-telemetry
summary: Retrieves the latest events received by an UEB topic
- description: This is a Network Communicaton Endpoint source of messages for
+ description: This is a Network Communication Endpoint source of messages for
the Engine
operationId: sinkEvents
parameters:
@@ -2533,7 +2533,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2563,7 +2563,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2596,7 +2596,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2631,7 +2631,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2662,7 +2662,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2692,7 +2692,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2725,7 +2725,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2759,7 +2759,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2792,7 +2792,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2826,7 +2826,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2859,7 +2859,7 @@ paths:
description: Communication Mechanism
required: true
schema:
- pattern: ueb|dmaap|noop
+ pattern: kafka|noop
type: string
- name: topic
in: path
@@ -2886,7 +2886,7 @@ paths:
tags:
- pdp-d-legacy
summary: Legacy Engine Configuration Properties
- description: Used for booststrapping the engine
+ description: Used for bootstrapping the engine
operationId: properties
responses:
200:
@@ -3822,80 +3822,6 @@ components:
$ref: '#/components/schemas/CoderFilters'
customCoder:
$ref: '#/components/schemas/CustomCoder'
- DmaapTopicSink:
- type: object
- properties:
- partitionKey:
- type: string
- apiKey:
- type: string
- apiSecret:
- type: string
- effectiveTopic:
- type: string
- recentEvents:
- type: array
- items:
- type: string
- topic:
- type: string
- servers:
- type: array
- items:
- type: string
- topicCommInfrastructure:
- type: string
- enum:
- - UEB
- - DMAAP
- - KAFKA
- - NOOP
- - REST
- alive:
- type: boolean
- locked:
- type: boolean
- DmaapTopicSource:
- type: object
- properties:
- consumerInstance:
- type: string
- consumerGroup:
- type: string
- fetchTimeout:
- type: integer
- format: int32
- fetchLimit:
- type: integer
- format: int32
- apiKey:
- type: string
- apiSecret:
- type: string
- effectiveTopic:
- type: string
- recentEvents:
- type: array
- items:
- type: string
- topic:
- type: string
- servers:
- type: array
- items:
- type: string
- topicCommInfrastructure:
- type: string
- enum:
- - UEB
- - DMAAP
- - KAFKA
- - NOOP
- - REST
- alive:
- type: boolean
- locked:
- type: boolean
KafkaTopicSink:
type: object
properties:
@@ -3920,8 +3846,6 @@ components:
topicCommInfrastructure:
type: string
enum:
- - UEB
- - DMAAP
- KAFKA
- NOOP
- REST
@@ -3992,8 +3916,6 @@ components:
topicCommInfrastructure:
type: string
enum:
- - UEB
- - DMAAP
- KAFKA
- NOOP
- REST
@@ -4019,26 +3941,12 @@ components:
topicCommInfrastructure:
type: string
enum:
- - UEB
- - DMAAP
- KAFKA
- NOOP
- REST
TopicEndpoint:
type: object
properties:
- uebTopicSources:
- type: array
- items:
- $ref: '#/components/schemas/UebTopicSource'
- uebTopicSinks:
- type: array
- items:
- $ref: '#/components/schemas/UebTopicSink'
- dmaapTopicSinks:
- type: array
- items:
- $ref: '#/components/schemas/DmaapTopicSink'
kafkaTopicSinks:
type: array
items:
@@ -4047,10 +3955,6 @@ components:
type: array
items:
$ref: '#/components/schemas/NoopTopicSink'
- dmaapTopicSources:
- type: array
- items:
- $ref: '#/components/schemas/DmaapTopicSource'
kafkaTopicSources:
type: array
items:
@@ -4071,80 +3975,6 @@ components:
type: boolean
locked:
type: boolean
- UebTopicSink:
- type: object
- properties:
- partitionKey:
- type: string
- apiKey:
- type: string
- apiSecret:
- type: string
- effectiveTopic:
- type: string
- recentEvents:
- type: array
- items:
- type: string
- topic:
- type: string
- servers:
- type: array
- items:
- type: string
- topicCommInfrastructure:
- type: string
- enum:
- - UEB
- - DMAAP
- - KAFKA
- - NOOP
- - REST
- alive:
- type: boolean
- locked:
- type: boolean
- UebTopicSource:
- type: object
- properties:
- consumerInstance:
- type: string
- consumerGroup:
- type: string
- fetchTimeout:
- type: integer
- format: int32
- fetchLimit:
- type: integer
- format: int32
- apiKey:
- type: string
- apiSecret:
- type: string
- effectiveTopic:
- type: string
- recentEvents:
- type: array
- items:
- type: string
- topic:
- type: string
- servers:
- type: array
- items:
- type: string
- topicCommInfrastructure:
- type: string
- enum:
- - UEB
- - DMAAP
- - KAFKA
- - NOOP
- - REST
- alive:
- type: boolean
- locked:
- type: boolean
PdpdConfiguration:
type: object
properties:
diff --git a/policy-management/src/main/resources/swagger/swagger.json b/policy-management/src/main/resources/swagger/swagger.json
index 9fb709b9..844c6c2d 100644
--- a/policy-management/src/main/resources/swagger/swagger.json
+++ b/policy-management/src/main/resources/swagger/swagger.json
@@ -3187,7 +3187,7 @@
"get" : {
"tags" : [ "pdp-d-telemetry" ],
"summary" : "Retrieves the managed topic sources",
- "description" : "Network Topic Sources Agregation",
+ "description" : "Network Topic Sources Aggregation",
"operationId" : "sources",
"responses" : {
"200" : {
@@ -3212,7 +3212,7 @@
"get" : {
"tags" : [ "pdp-d-telemetry" ],
"summary" : "Retrieves the managed topic sinks",
- "description" : "Network Topic Sinks Agregation",
+ "description" : "Network Topic Sinks Aggregation",
"operationId" : "sinks",
"responses" : {
"200" : {
@@ -3328,7 +3328,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
} ],
@@ -3365,7 +3365,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
} ],
@@ -3402,7 +3402,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3439,7 +3439,7 @@
"get" : {
"tags" : [ "pdp-d-telemetry" ],
"summary" : "Retrieves a managed topic sink",
- "description" : "This is a Network Communicaton Endpoint destination of messages from the Engine",
+ "description" : "This is a Network Communication Endpoint destination of messages from the Engine",
"operationId" : "sinkTopic",
"parameters" : [ {
"name" : "comm",
@@ -3449,7 +3449,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3496,7 +3496,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3541,7 +3541,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3602,7 +3602,7 @@
"get" : {
"tags" : [ "pdp-d-telemetry" ],
"summary" : "Retrieves the latest events received by an UEB topic",
- "description" : "This is a Network Communicaton Endpoint source of messages for the Engine",
+ "description" : "This is a Network Communication Endpoint source of messages for the Engine",
"operationId" : "sinkEvents",
"parameters" : [ {
"name" : "comm",
@@ -3612,7 +3612,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3658,7 +3658,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3706,7 +3706,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3757,7 +3757,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3804,7 +3804,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3850,7 +3850,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3898,7 +3898,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3948,7 +3948,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -3996,7 +3996,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -4046,7 +4046,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -4094,7 +4094,7 @@
"style" : "simple",
"explode" : false,
"schema" : {
- "pattern" : "ueb|dmaap|noop",
+ "pattern" : "kafka|noop",
"type" : "string"
}
}, {
@@ -4135,7 +4135,7 @@
"get" : {
"tags" : [ "pdp-d-legacy" ],
"summary" : "Legacy Engine Configuration Properties",
- "description" : "Used for booststrapping the engine",
+ "description" : "Used for bootstrapping the engine",
"operationId" : "properties",
"responses" : {
"200" : {
@@ -5486,101 +5486,6 @@
}
}
},
- "DmaapTopicSink" : {
- "type" : "object",
- "properties" : {
- "partitionKey" : {
- "type" : "string"
- },
- "apiKey" : {
- "type" : "string"
- },
- "apiSecret" : {
- "type" : "string"
- },
- "effectiveTopic" : {
- "type" : "string"
- },
- "recentEvents" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topic" : {
- "type" : "string"
- },
- "servers" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topicCommInfrastructure" : {
- "type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
- },
- "alive" : {
- "type" : "boolean"
- },
- "locked" : {
- "type" : "boolean"
- }
- }
- },
- "DmaapTopicSource" : {
- "type" : "object",
- "properties" : {
- "consumerInstance" : {
- "type" : "string"
- },
- "consumerGroup" : {
- "type" : "string"
- },
- "fetchTimeout" : {
- "type" : "integer",
- "format" : "int32"
- },
- "fetchLimit" : {
- "type" : "integer",
- "format" : "int32"
- },
- "apiKey" : {
- "type" : "string"
- },
- "apiSecret" : {
- "type" : "string"
- },
- "effectiveTopic" : {
- "type" : "string"
- },
- "recentEvents" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topic" : {
- "type" : "string"
- },
- "servers" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topicCommInfrastructure" : {
- "type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
- },
- "alive" : {
- "type" : "boolean"
- },
- "locked" : {
- "type" : "boolean"
- }
- }
- },
"KafkaTopicSink" : {
"type" : "object",
"properties" : {
@@ -5613,7 +5518,7 @@
},
"topicCommInfrastructure" : {
"type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
+ "enum" : [ "KAFKA", "NOOP", "REST" ]
},
"alive" : {
"type" : "boolean"
@@ -5705,7 +5610,7 @@
},
"topicCommInfrastructure" : {
"type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
+ "enum" : [ "KAFKA", "NOOP", "REST" ]
}
}
},
@@ -5738,31 +5643,13 @@
},
"topicCommInfrastructure" : {
"type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
+ "enum" : [ "KAFKA", "NOOP", "REST" ]
}
}
},
"TopicEndpoint" : {
"type" : "object",
"properties" : {
- "uebTopicSources" : {
- "type" : "array",
- "items" : {
- "$ref" : "#/components/schemas/UebTopicSource"
- }
- },
- "uebTopicSinks" : {
- "type" : "array",
- "items" : {
- "$ref" : "#/components/schemas/UebTopicSink"
- }
- },
- "dmaapTopicSinks" : {
- "type" : "array",
- "items" : {
- "$ref" : "#/components/schemas/DmaapTopicSink"
- }
- },
"kafkaTopicSinks" : {
"type" : "array",
"items" : {
@@ -5775,12 +5662,6 @@
"$ref" : "#/components/schemas/NoopTopicSink"
}
},
- "dmaapTopicSources" : {
- "type" : "array",
- "items" : {
- "$ref" : "#/components/schemas/DmaapTopicSource"
- }
- },
"kafkaTopicSources" : {
"type" : "array",
"items" : {
@@ -5813,101 +5694,6 @@
}
}
},
- "UebTopicSink" : {
- "type" : "object",
- "properties" : {
- "partitionKey" : {
- "type" : "string"
- },
- "apiKey" : {
- "type" : "string"
- },
- "apiSecret" : {
- "type" : "string"
- },
- "effectiveTopic" : {
- "type" : "string"
- },
- "recentEvents" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topic" : {
- "type" : "string"
- },
- "servers" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topicCommInfrastructure" : {
- "type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
- },
- "alive" : {
- "type" : "boolean"
- },
- "locked" : {
- "type" : "boolean"
- }
- }
- },
- "UebTopicSource" : {
- "type" : "object",
- "properties" : {
- "consumerInstance" : {
- "type" : "string"
- },
- "consumerGroup" : {
- "type" : "string"
- },
- "fetchTimeout" : {
- "type" : "integer",
- "format" : "int32"
- },
- "fetchLimit" : {
- "type" : "integer",
- "format" : "int32"
- },
- "apiKey" : {
- "type" : "string"
- },
- "apiSecret" : {
- "type" : "string"
- },
- "effectiveTopic" : {
- "type" : "string"
- },
- "recentEvents" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topic" : {
- "type" : "string"
- },
- "servers" : {
- "type" : "array",
- "items" : {
- "type" : "string"
- }
- },
- "topicCommInfrastructure" : {
- "type" : "string",
- "enum" : [ "UEB", "DMAAP", "KAFKA", "NOOP", "REST" ]
- },
- "alive" : {
- "type" : "boolean"
- },
- "locked" : {
- "type" : "boolean"
- }
- }
- },
"PdpdConfiguration" : {
"type" : "object",
"properties" : {
diff --git a/policy-management/src/test/java/org/onap/policy/drools/server/restful/test/RestManagerTest.java b/policy-management/src/test/java/org/onap/policy/drools/server/restful/test/RestManagerTest.java
index 65447d80..6a17f269 100644
--- a/policy-management/src/test/java/org/onap/policy/drools/server/restful/test/RestManagerTest.java
+++ b/policy-management/src/test/java/org/onap/policy/drools/server/restful/test/RestManagerTest.java
@@ -69,26 +69,18 @@ public class RestManagerTest {
private static final String TELEMETRY_USER = "x";
private static final String TELEMETRY_PASSWORD = "y";
private static final String FOO_CONTROLLER = "foo";
-
- private static final String UEB_TOPIC = "ueb-topic-test";
private static final String KAFKA_TOPIC = "kafka-topic-test";
private static final String NOOP_TOPIC = "noop_topic";
-
- private static final String UEB_SOURCE_SERVER_PROPERTY = PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "."
- + UEB_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
- private static final String UEB_SINK_SERVER_PROPERTY = PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS + "."
- + UEB_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
private static final String KAFKA_SOURCE_SERVER_PROPERTY = PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS
- + "." + KAFKA_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
+ + "." + KAFKA_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
private static final String KAFKA_SINK_SERVER_PROPERTY = PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS + "."
- + KAFKA_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
- private static final String UEB_SERVER = "localhost";
+ + KAFKA_TOPIC + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX;
private static final String KAFKA_SERVER = "localhost:9092";
private static final String FOO_CONTROLLER_FILE = FOO_CONTROLLER + "-controller.properties";
private static final String FOO_CONTROLLER_FILE_BAK = FOO_CONTROLLER_FILE + ".bak";
private static final String PDP_CONFIGURATION_JSON =
- "src/test/resources/org/onap/policy/drools/server/restful/PdpConfiguration.json";
+ "src/test/resources/org/onap/policy/drools/server/restful/PdpConfiguration.json";
private static CloseableHttpClient client;
@@ -108,28 +100,24 @@ public class RestManagerTest {
/* override default port */
final Properties engineProps = PolicyEngineConstants.getManager().defaultTelemetryConfig();
engineProps.put(PolicyEndPointProperties.PROPERTY_HTTP_SERVER_SERVICES + "."
- + PolicyEngineConstants.TELEMETRY_SERVER_DEFAULT_NAME
- + PolicyEndPointProperties.PROPERTY_HTTP_PORT_SUFFIX, "" + DEFAULT_TELEMETRY_PORT);
+ + PolicyEngineConstants.TELEMETRY_SERVER_DEFAULT_NAME
+ + PolicyEndPointProperties.PROPERTY_HTTP_PORT_SUFFIX, "" + DEFAULT_TELEMETRY_PORT);
engineProps.put(PolicyEndPointProperties.PROPERTY_HTTP_SERVER_SERVICES + "."
+ PolicyEngineConstants.TELEMETRY_SERVER_DEFAULT_NAME
+ PolicyEndPointProperties.PROPERTY_HTTP_AUTH_USERNAME_SUFFIX,
- TELEMETRY_USER);
+ TELEMETRY_USER);
engineProps.put(PolicyEndPointProperties.PROPERTY_HTTP_SERVER_SERVICES + "."
+ PolicyEngineConstants.TELEMETRY_SERVER_DEFAULT_NAME
+ PolicyEndPointProperties.PROPERTY_HTTP_AUTH_PASSWORD_SUFFIX,
- TELEMETRY_PASSWORD);
+ TELEMETRY_PASSWORD);
engineProps.put(PolicyEndPointProperties.PROPERTY_HTTP_SERVER_SERVICES + "."
+ PolicyEngineConstants.TELEMETRY_SERVER_DEFAULT_NAME
+ PolicyEndPointProperties.PROPERTY_HTTP_SERIALIZATION_PROVIDER,
- String.join(",", JacksonHandler.class.getName(), YamlJacksonHandler.class.getName()));
+ String.join(",", JacksonHandler.class.getName(), YamlJacksonHandler.class.getName()));
/* other properties */
- engineProps.put(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS, UEB_TOPIC);
- engineProps.put(PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS, UEB_TOPIC);
engineProps.put(PolicyEndPointProperties.PROPERTY_KAFKA_SOURCE_TOPICS, KAFKA_TOPIC);
engineProps.put(PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS, KAFKA_TOPIC);
- engineProps.put(UEB_SOURCE_SERVER_PROPERTY, UEB_SERVER);
- engineProps.put(UEB_SINK_SERVER_PROPERTY, UEB_SERVER);
engineProps.put(KAFKA_SOURCE_SERVER_PROPERTY, KAFKA_SERVER);
engineProps.put(KAFKA_SINK_SERVER_PROPERTY, KAFKA_SERVER);
@@ -197,41 +185,30 @@ public class RestManagerTest {
}
private void putDeleteTopicSwitches() throws IOException {
- putDeleteSwitch("/engine/topics/sources/ueb/", UEB_TOPIC, "lock");
putDeleteSwitch("/engine/topics/sources/kafka/", KAFKA_TOPIC, "lock");
putDeleteSwitch("/engine/topics/sources/noop/", NOOP_TOPIC, "lock");
- putDeleteSwitch("/engine/topics/sinks/ueb/", UEB_TOPIC, "lock");
putDeleteSwitch("/engine/topics/sinks/kafka/", KAFKA_TOPIC, "lock");
putDeleteSwitch("/engine/topics/sinks/noop/", NOOP_TOPIC, "lock");
- putDeleteSwitch("/engine/topics/sources/ueb/", UEB_TOPIC, "activation");
putDeleteSwitch("/engine/topics/sources/kafka/", KAFKA_TOPIC, "activation");
putDeleteSwitch("/engine/topics/sources/noop/", NOOP_TOPIC, "activation");
- putDeleteSwitch("/engine/topics/sinks/ueb/", UEB_TOPIC, "activation");
putDeleteSwitch("/engine/topics/sinks/kafka/", KAFKA_TOPIC, "activation");
putDeleteSwitch("/engine/topics/sinks/noop/", NOOP_TOPIC, "activation");
- putSwitch("/engine/topics/sources/ueb/", UEB_TOPIC, "activation");
putSwitch("/engine/topics/sources/kafka/", KAFKA_TOPIC, "activation");
putSwitch("/engine/topics/sources/noop/", NOOP_TOPIC, "activation");
- putSwitch("/engine/topics/sinks/ueb/", UEB_TOPIC, "activation");
putSwitch("/engine/topics/sinks/kafka/", KAFKA_TOPIC, "activation");
putSwitch("/engine/topics/sinks/noop/", NOOP_TOPIC, "activation");
}
private void putDeleteTopicsSources() throws IOException {
- putTest(HOST_URL + "/engine/topics/sources/ueb/" + UEB_TOPIC + "/events", 200,
- "{x:y}", ContentType.TEXT_PLAIN);
putTest(HOST_URL + "/engine/topics/sources/noop/" + NOOP_TOPIC + "/events", 200,
"{x:y}", ContentType.TEXT_PLAIN);
putTest(HOST_URL + "/engine/topics/sources/kafka/" + KAFKA_TOPIC + "/events", 200,
"FOOOO", ContentType.TEXT_PLAIN);
- putTest(HOST_URL + "/engine/topics/sources/ueb/fiznits/events", 406, "FOOOO", ContentType.TEXT_PLAIN);
putTest(HOST_URL + "/engine/topics/sources/kafka/fiznits/events", 406,
"FOOOO", ContentType.TEXT_PLAIN);
putTest(HOST_URL + "/engine/topics/switches/lock", 200);
- putTest(HOST_URL + "/engine/topics/sources/ueb/" + UEB_TOPIC + "/events",
- 406, "FOOOO", ContentType.TEXT_PLAIN);
putTest(HOST_URL + "/engine/topics/sources/kafka/" + KAFKA_TOPIC + "/events",
406, "FOOOO", ContentType.TEXT_PLAIN);
deleteTest(HOST_URL + "/engine/topics/switches/lock", 200);
@@ -246,10 +223,10 @@ public class RestManagerTest {
deleteTest(HOST_URL + "/engine/controllers/" + FOO_CONTROLLER, 200);
}
- private void postTest(String uri, int statusCode, String payload, ContentType contentType) throws IOException {
+ private void postTest(String uri, int statusCode, String payload) throws IOException {
HttpPost post = new HttpPost(uri);
- if (contentType != null) {
- post.setEntity(new StringEntity(payload, contentType));
+ if (ContentType.APPLICATION_JSON != null) {
+ post.setEntity(new StringEntity(payload, ContentType.APPLICATION_JSON));
}
requestTest(post, statusCode);
}
@@ -293,28 +270,19 @@ public class RestManagerTest {
@Test
void testPost() throws IOException {
postTest(HOST_URL + "/engine/inputs/configuration", 406,
- Files.readString(Paths.get(PDP_CONFIGURATION_JSON)),
- ContentType.APPLICATION_JSON);
+ Files.readString(Paths.get(PDP_CONFIGURATION_JSON)));
- postTest(HOST_URL + "/engine/controllers", 400,
- "{}",
- ContentType.APPLICATION_JSON);
+ postTest(HOST_URL + "/engine/controllers", 400, "{}");
- postTest(HOST_URL + "/engine/controllers", 304,
- "{controller.name : foo}",
- ContentType.APPLICATION_JSON);
+ postTest(HOST_URL + "/engine/controllers", 304, "{controller.name : foo}");
- postTest(HOST_URL + "/engine/controllers", 206,
- "{controller.name : new}",
- ContentType.APPLICATION_JSON);
+ postTest(HOST_URL + "/engine/controllers", 206, "{controller.name : new}");
deleteTest(HOST_URL + "/engine/controllers/new", 200);
- postTest(HOST_URL + "/engine/controllers/foo/drools/facts/session1/query1/entity1", 200,
- "[{f:v}]", ContentType.APPLICATION_JSON);
+ postTest(HOST_URL + "/engine/controllers/foo/drools/facts/session1/query1/entity1", 200, "[{f:v}]");
- postTest(HOST_URL + "/engine/controllers/new/drools/facts/session1/query1/entity1", 404,
- "[{f:v}]", ContentType.APPLICATION_JSON);
+ postTest(HOST_URL + "/engine/controllers/new/drools/facts/session1/query1/entity1", 404, "[{f:v}]");
}
@Test
@@ -491,6 +459,18 @@ public class RestManagerTest {
assertEquals(404, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
+ testGetDroolsControllers();
+
+ testGetControllersDecoders();
+
+ testGetTopics();
+
+ testGetEngineTools();
+ }
+
+ private static void testGetDroolsControllers() throws IOException {
+ CloseableHttpResponse response;
+ HttpGet httpGet;
/*
* GET: /engine/controllers/controllerName/drools/facts
* /engine/controllers/controllerName/drools/facts/session
@@ -523,7 +503,7 @@ public class RestManagerTest {
httpGet.releaseConnection();
httpGet = new HttpGet(
- HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/drools/facts/session/query/queriedEntity");
+ HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/drools/facts/session/query/queriedEntity");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(200, response.getStatusLine().getStatusCode());
@@ -534,8 +514,36 @@ public class RestManagerTest {
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(404, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
+ }
+ private static void testGetEngineTools() throws IOException {
+ CloseableHttpResponse response;
+ HttpGet httpGet;
+ /*
+ * GET: /engine/tools/uuid /engine/tools/loggers /engine/tools/loggers/loggerName
+ */
+ httpGet = new HttpGet(HOST_URL + "/engine/tools/uuid");
+ response = client.execute(httpGet);
+ logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
+ assertEquals(200, response.getStatusLine().getStatusCode());
+ httpGet.releaseConnection();
+ httpGet = new HttpGet(HOST_URL + "/engine/tools/loggers");
+ response = client.execute(httpGet);
+ logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
+ assertEquals(200, response.getStatusLine().getStatusCode());
+ httpGet.releaseConnection();
+
+ httpGet = new HttpGet(HOST_URL + "/engine/tools/loggers/ROOT");
+ response = client.execute(httpGet);
+ logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
+ assertEquals(200, response.getStatusLine().getStatusCode());
+ httpGet.releaseConnection();
+ }
+
+ private static void testGetControllersDecoders() throws IOException {
+ HttpGet httpGet;
+ CloseableHttpResponse response;
/*
* GET: /engine/controllers/controllerName/decoders
* /engine/controllers/controllerName/decoders/filters
@@ -589,14 +597,14 @@ public class RestManagerTest {
httpGet.releaseConnection();
httpGet = new HttpGet(
- HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/decoders/topic/filters/factType/rules");
+ HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/decoders/topic/filters/factType/rules");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(404, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
httpGet = new HttpGet(
- HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/decoders/topic/filters/factType/rules/ruleName");
+ HOST_URL + "/engine/controllers/" + FOO_CONTROLLER + "/decoders/topic/filters/factType/rules/ruleName");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(404, response.getStatusLine().getStatusCode());
@@ -607,15 +615,22 @@ public class RestManagerTest {
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(200, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
+ }
+ private static void testGetTopics() throws IOException {
+ CloseableHttpResponse response;
+ HttpGet httpGet;
/*
- * GET: /engine/topics /engine/topics/switches /engine/topics/sources /engine/topics/sinks
- * /engine/topics/sinks/ueb /engine/topics/sources/ueb /engine/topics/sinks/kafka
- * /engine/topics/sources/kafka /engine/topics/sinks/ueb/topic
- * /engine/topics/sources/ueb/topic /engine/topics/sinks/kafka/topic
- * /engine/topics/sources/kafka/topic /engine/topics/sinks/ueb/topic/events
- * /engine/topics/sources/ueb/topic/events /engine/topics/sinks/kafka/topic/events
- * /engine/topics/sources/kafka/topic/events /engine/topics/sources/ueb/topic/switches
+ * GET: /engine/topics
+ * /engine/topics/switches
+ * /engine/topics/sources
+ * /engine/topics/sinks
+ * /engine/topics/sinks/kafka
+ * /engine/topics/sources/kafka
+ * /engine/topics/sinks/kafka/topic
+ * /engine/topics/sources/kafka/topic
+ * /engine/topics/sinks/kafka/topic/events
+ * /engine/topics/sources/kafka/topic/events
* /engine/topics/sources/kafka/topic/switches
*/
httpGet = new HttpGet(HOST_URL + "/engine/topics");
@@ -642,18 +657,6 @@ public class RestManagerTest {
assertEquals(200, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/kafka");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
@@ -678,30 +681,6 @@ public class RestManagerTest {
assertEquals(200, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb/" + UEB_TOPIC);
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb/foobar");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(500, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb/" + UEB_TOPIC);
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb/foobar");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(500, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/kafka/" + KAFKA_TOPIC);
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
@@ -750,30 +729,6 @@ public class RestManagerTest {
assertEquals(500, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb/" + UEB_TOPIC + "/events");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb/foobar/events");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(500, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb/" + UEB_TOPIC + "/events");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb/foobar/events");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(500, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/kafka/" + KAFKA_TOPIC + "/events");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
@@ -822,12 +777,6 @@ public class RestManagerTest {
assertEquals(500, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/ueb/" + UEB_TOPIC + "/switches");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
httpGet = new HttpGet(HOST_URL + "/engine/topics/sources/kafka/" + KAFKA_TOPIC + "/switches");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
@@ -840,12 +789,6 @@ public class RestManagerTest {
assertEquals(200, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
- httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/ueb/" + UEB_TOPIC + "/switches");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
httpGet = new HttpGet(HOST_URL + "/engine/topics/sinks/kafka/" + KAFKA_TOPIC + "/switches");
response = client.execute(httpGet);
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
@@ -857,27 +800,6 @@ public class RestManagerTest {
logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
assertEquals(200, response.getStatusLine().getStatusCode());
httpGet.releaseConnection();
-
- /*
- * GET: /engine/tools/uuid /engine/tools/loggers /engine/tools/loggers/loggerName
- */
- httpGet = new HttpGet(HOST_URL + "/engine/tools/uuid");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/tools/loggers");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
-
- httpGet = new HttpGet(HOST_URL + "/engine/tools/loggers/ROOT");
- response = client.execute(httpGet);
- logger.info(httpGet.getRequestLine() + " response code: {}", response.getStatusLine().getStatusCode());
- assertEquals(200, response.getStatusLine().getStatusCode());
- httpGet.releaseConnection();
}
/**
@@ -902,10 +824,10 @@ public class RestManagerTest {
private static void cleanUpWorkingDirs() throws IOException {
final Path testControllerPath = Paths.get(
- SystemPersistenceConstants.getManager().getConfigurationPath().toString(), FOO_CONTROLLER_FILE);
+ SystemPersistenceConstants.getManager().getConfigurationPath().toString(), FOO_CONTROLLER_FILE);
final Path testControllerBakPath =
- Paths.get(SystemPersistenceConstants.getManager().getConfigurationPath().toString(),
- FOO_CONTROLLER_FILE_BAK);
+ Paths.get(SystemPersistenceConstants.getManager().getConfigurationPath().toString(),
+ FOO_CONTROLLER_FILE_BAK);
Files.deleteIfExists(testControllerPath);
Files.deleteIfExists(testControllerBakPath);
diff --git a/policy-management/src/test/java/org/onap/policy/drools/system/PolicyEngineTest.java b/policy-management/src/test/java/org/onap/policy/drools/system/PolicyEngineTest.java
index a6b8ac3f..20622091 100644
--- a/policy-management/src/test/java/org/onap/policy/drools/system/PolicyEngineTest.java
+++ b/policy-management/src/test/java/org/onap/policy/drools/system/PolicyEngineTest.java
@@ -33,7 +33,6 @@ import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Properties;
import java.util.concurrent.TimeUnit;
-import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.MethodOrderer;
import org.junit.jupiter.api.Test;
diff --git a/pom.xml b/pom.xml
index 5ebd052f..710d05f0 100644
--- a/pom.xml
+++ b/pom.xml
@@ -84,6 +84,10 @@
<scope>provided</scope>
</dependency>
<dependency>
+ <groupId>org.slf4j</groupId>
+ <artifactId>slf4j-api</artifactId>
+ </dependency>
+ <dependency>
<groupId>org.onap.policy.common</groupId>
<artifactId>utils-test</artifactId>
<version>${policy.common.version}</version>
diff --git a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
index 31ad207c..ac2b31a8 100644
--- a/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
+++ b/feature-pooling-messages/src/test/java/org/onap/policy/drools/pooling/EndToEndFeatureTest.java
@@ -76,9 +76,9 @@ public class EndToEndFeatureTest {
private static final Logger logger = LoggerFactory.getLogger(EndToEndFeatureTest.class);
/**
* UEB servers for both internal & external topics.
*/
- private static final String UEB_SERVERS = "ueb-server";
+ private static final String SERVER = "localhost:9092";
/**
* Name of the topic used for inter-host communication.
@@ -101,7 +101,7 @@ public class EndToEndFeatureTest {
private static final String CONTROLLER1 = "controller.one";
/**
* Maximum number of items to fetch from DMaaP in a single poll.
*/
private static final String FETCH_LIMIT = "5";
@@ -124,12 +124,12 @@ public class EndToEndFeatureTest {
private static final ThreadLocal<Host> currentHost = new ThreadLocal<Host>();
/**
* Sink for external DMaaP topic.
*/
private static TopicSink externalSink;
/**
* Sink for internal DMaaP topic.
*/
private static TopicSink internalSink;
@@ -237,13 +237,13 @@ public class EndToEndFeatureTest {
private static Properties makeSinkProperties(String topic) {
Properties props = new Properties();
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS, topic);
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS, topic);
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS + "." + topic
- + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX, UEB_SERVERS);
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS + "." + topic
+ + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX, SERVER);
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_TOPIC_SINK_PARTITION_KEY_SUFFIX, "0");
- props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SINK_TOPICS + "." + topic
+ props.setProperty(PolicyEndPointProperties.PROPERTY_KAFKA_SINK_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_MANAGED_SUFFIX, "false");
return props;
@@ -255,7 +255,7 @@ public class EndToEndFeatureTest {
props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS, topic);
props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
- + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX, UEB_SERVERS);
+ + PolicyEndPointProperties.PROPERTY_TOPIC_SERVERS_SUFFIX, SERVER);
props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
+ PolicyEndPointProperties.PROPERTY_TOPIC_SOURCE_FETCH_LIMIT_SUFFIX, FETCH_LIMIT);
props.setProperty(PolicyEndPointProperties.PROPERTY_UEB_SOURCE_TOPICS + "." + topic
@@ -348,14 +348,14 @@ public class EndToEndFeatureTest {
* Starts the hosts.
*/
public void startHosts() {
- hosts.forEach(host -> host.start());
+ hosts.forEach(Host::start);
}
/**
* Stops the hosts.
*/
public void stopHosts() {
- hosts.forEach(host -> host.stop());
+ hosts.forEach(Host::stop);
}
/**
@@ -489,10 +489,10 @@ public class EndToEndFeatureTest {
when(controller.getName()).thenReturn(CONTROLLER1);
when(controller.getDrools()).thenReturn(drools);
- externalSource = TopicEndpointManager.getManager().addTopicSources(makeSourceProperties(EXTERNAL_TOPIC))
- .get(0);
- internalSource = TopicEndpointManager.getManager().addTopicSources(makeSourceProperties(INTERNAL_TOPIC))
- .get(0);
+ externalSource = TopicEndpointManager.getManager()
+ .addTopicSources(makeSourceProperties(EXTERNAL_TOPIC)).get(0);
+ internalSource = TopicEndpointManager.getManager()
+ .addTopicSources(makeSourceProperties(INTERNAL_TOPIC)).get(0);
// stop consuming events if the controller stops
when(controller.stop()).thenAnswer(args -> {
@@ -646,7 +646,7 @@ public class EndToEndFeatureTest {
if (!host.beforeInsert(fact)) {
// feature did not handle it so we handle it here
- host.afterInsert(fact, result);
+ host.afterInsert(fact, true);
host.sawMessage();
context.addEvent();
@@ -76,9 +76,9 @@ public class EndToEndFeatureTest {
private static final Logger logger = LoggerFactory.getLogger(EndToEndFeatureTest.class);
/**
- * UEB servers for both internal & external topics.
+ * KAFKA servers for both internal & external topics.
*/
@@ -101,7 +101,7 @@ public class EndToEndFeatureTest {
private static final String CONTROLLER1 = "controller.one";
/**
- * Maximum number of items to fetch from DMaaP in a single poll.
+ * Maximum number of items to fetch from Kafka in a single poll.
*/
private static final String FETCH_LIMIT = "5";
@@ -124,12 +124,12 @@ public class EndToEndFeatureTest {
private static final ThreadLocal<Host> currentHost = new ThreadLocal<Host>();
/**
- * Sink for external DMaaP topic.
+ * Sink for external Kafka topic.
*/
private static TopicSink externalSink;
@@ -124,12 +124,12 @@ public class EndToEndFeatureTest {
private static TopicSink externalSink;
/**
- * Sink for internal DMaaP topic.
+ * Sink for internal Kafka topic.
*/
private static TopicSink internalSink;